# γEKO

γEKO (pronouced [geko]) is a Python module to solve the point-like contribution to the photon evolution. It is closely related to [eko](https://github.com/NNPDF/eko).

[![Version](https://img.shields.io/pypi/v/geko.svg)](https://pypi.python.org/pypi/geko)
[![License](https://img.shields.io/pypi/l/geko.svg)](https://github.com/felixhekhorn/geko/blob/main/LICENSE)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/geko.svg)](https://pypi.python.org/pypi/geko)
[![Python unit tests](https://github.com/felixhekhorn/geko/actions/workflows/unittests.yml/badge.svg)](https://github.com/felixhekhorn/geko/actions/workflows/unittests.yml)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
